@@ -284,9 +284,6 @@ gen_raw_wml <- function(x, ...) {
   dims <- dim(x)
   widths <- dims$widths
 
-  x <- keep_wn(x, part = "all",
-               keep_with_next = x$properties$opts_word$keep_with_next)
-
   out <- paste0(
     "<w:tbl xmlns:w=\"http://schemas.openxmlformats.org/wordprocessingml/2006/main\" ",
     "xmlns:r=\"http://schemas.openxmlformats.org/officeDocument/2006/relationships\" ",
