@@ -291,7 +291,7 @@ set_caption <- function(x,
                         autonum = NULL,
                         word_stylename = "Table Caption",
                         style = word_stylename,
-                        fp_p = NULL,
+                        fp_p = fp_par(padding = 3),
                         align_with_table = TRUE,
                         html_classes = NULL,
                         html_escape = TRUE) {
@@ -335,6 +335,42 @@ set_caption <- function(x,
 
   x
 }
+update_caption <- function(x, caption = NULL,
+                           autonum = NULL,
+                           word_stylename = NULL,
+                           fp_p = NULL,
+                           align_with_table = NULL,
+                           html_classes = NULL) {
+  if (!is.null(caption)) {
+    if (inherits(caption, "paragraph")) {
+      x$caption$simple_caption <- FALSE
+    } else {
+      x$caption$simple_caption <- TRUE
+    }
+    x$caption$value <- caption
+  }
+
+  if (!is.null(autonum)) {
+    x$caption$autonum <- autonum
+  }
+
+  if (!is.null(fp_p)) {
+    x$caption$fp_p <- fp_p
+  }
+
+  if (!is.null(word_stylename)) {
+    x$caption$word_stylename <- word_stylename
+  }
+  if (!is.null(html_classes)) {
+    x$caption$html_classes <- html_classes
+  }
+  if (!is.null(align_with_table)) {
+    x$caption$align_with_table <- align_with_table
+  }
+
+  x
+}
+
 
 #' @keywords internal
 #' @title flextable old functions
@@ -376,9 +412,6 @@ regulartable <- function( data, col_keys = names(data), cwidth = .75, cheight =
 #' @param align alignment in document (only Word, HTML and PDF),
 #' supported values are 'left', 'center' and 'right'.
 #' @param opts_html html options as a list. Supported elements are:
-#' - 'shadow' `TRUE` or `FALSE`, use shadow dom, this option is existing
-#' to disable shadow dom (set to `FALSE`) for pagedown and Quarto that can
-#' not support it for now.
 #' - 'extra_css': extra css instructions to be integrated with the HTML
 #' code of the table.
 #' - 'scroll': NULL or a list if you want to add a scroll-box.
@@ -439,7 +472,6 @@ regulartable <- function( data, col_keys = names(data), cwidth = .75, cheight =
 #' ft_4 <- set_table_properties(
 #'   x = ft_4,
 #'   opts_html = list(
-#'     shadow = FALSE,
 #'     scroll = list(
 #'       height = "500px",
 #'       freeze_first_column = TRUE
@@ -480,13 +512,10 @@ set_table_properties <- function(x, layout = "fixed", width = 0,
   x
 }
 
-opts_ft_html <- function(shadow = get_flextable_defaults()$shadow,
-                         extra_css = get_flextable_defaults()$extra_css,
-                         scroll = get_flextable_defaults()$scroll) {
+opts_ft_html <- function(extra_css = get_flextable_defaults()$extra_css,
+                         scroll = get_flextable_defaults()$scroll,
+                         ...) {
 
-  if( !is.logical(shadow) || length(shadow) != 1 ){
-    stop(sprintf("'%s' is expected to be a single %s.", "shadow", "logical"), call. = FALSE)
-  }
   if(!is.character(extra_css) || length(extra_css) != 1 || any(is.na(extra_css))){
     stop(sprintf("'%s' is expected to be a single %s.", "extra_css", "character"), call. = FALSE)
   }
@@ -494,7 +523,7 @@ opts_ft_html <- function(shadow = get_flextable_defaults()$shadow,
     stop(sprintf("'%s' is expected to be %s.", "scroll", "NULL or a list"), call. = FALSE)
   }
 
-  z <- list(shadow = shadow, extra_css = extra_css, scroll = scroll)
+  z <- list(extra_css = extra_css, scroll = scroll)
   class(z) <- "opts_ft_html"
   z
 }
@@ -543,7 +572,7 @@ opts_ft_pdf <- function(tabcolsep = get_flextable_defaults()$tabcolsep,
 
 #' @export
 knit_print.run_reference <- function(x, ...){
-  is_quarto <- isTRUE(knitr::opts_knit$get("quarto.version") > numeric_version("0"))
+  is_quarto <- is_in_quarto()
   title <- ""
   if (is_quarto) {
     title <- opts_current_table()$cap.pre
